@@ -27,7 +27,6 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QSharedData>
-#include <QDebug>
 
 #include <kconfiggroup.h>
 #include "krunner_debug.h"
@@ -137,8 +136,8 @@ bool correctPathCase(const QString& path, QString &corrected)
     }
 
     QString correctPath;
-    const unsigned initialComponents = components.size();
-    for (unsigned i = 0; i < initialComponents - 1; i ++) {
+    const int initialComponents = components.size();
+    for (int i = 0; i < initialComponents - 1; i++) {
         const QString tmp = components[0] + QDir::separator() + components[1];
 
         if (!correctLastComponentCase(tmp, correctPath, components.size() > 2 || mustBeDir)) {
@@ -191,7 +190,7 @@ class RunnerContextPrivate : public QSharedData
             type = RunnerContext::UnknownType;
             QString path = QDir::cleanPath(KShell::tildeExpand(term));
 
-            int space = path.indexOf(' ');
+            int space = path.indexOf(QLatin1Char(' '));
             if (!QStandardPaths::findExecutable(path.left(space)).isEmpty()) {
                 // it's a shell command if there's a space because that implies
                 // that it has arguments!
@@ -207,7 +206,7 @@ class RunnerContextPrivate : public QSharedData
                     }
                 }
                 const bool hasProtocol = !url.scheme().isEmpty();
-                const bool isLocalProtocol = KProtocolInfo::protocolClass(url.scheme()) == QLatin1String(":local");
+                const bool isLocalProtocol = hasProtocol && KProtocolInfo::protocolClass(url.scheme()) == QLatin1String(":local");
                 if (hasProtocol &&
                     ((!isLocalProtocol && !url.host().isEmpty()) ||
                      (isLocalProtocol && url.scheme() != QLatin1String("file")))) {
@@ -220,7 +219,7 @@ class RunnerContextPrivate : public QSharedData
                     // it's too ambiguous to be sure we're in a filesystem context
                     path = QDir::cleanPath(url.toLocalFile());
                     //qCDebug(KRUNNER)<< "slash check" << path;
-                    if (hasProtocol || ((path.indexOf('/') != -1 || path.indexOf('\\') != -1))) {
+                    if (hasProtocol || ((path.indexOf(QLatin1Char('/')) != -1 || path.indexOf(QLatin1Char('\\')) != -1))) {
                         QString correctCasePath;
                         if (correctPathCase(path, correctCasePath)) {
                             path = correctCasePath;
@@ -456,7 +455,7 @@ bool RunnerContext::removeMatches(const QStringList matchIdList)
 
     LOCK_FOR_READ(d)
     foreach(const QString &matchId, matchIdList) {
-        const QueryMatch* match = d->matchesById.value(matchId, 0);
+        const QueryMatch* match = d->matchesById.value(matchId, nullptr);
         if (match) {
             presentMatchList << match;
             presentMatchIdList << matchId;
@@ -488,7 +487,7 @@ bool RunnerContext::removeMatch(const QString matchId)
         return false;
     }
     LOCK_FOR_READ(d)
-    const QueryMatch* match = d->matchesById.value(matchId, 0);
+    const QueryMatch* match = d->matchesById.value(matchId, nullptr);
     UNLOCK(d)
     if (!match) {
         return false;
@@ -544,14 +543,14 @@ QList<QueryMatch> RunnerContext::matches() const
 QueryMatch RunnerContext::match(const QString &id) const
 {
     LOCK_FOR_READ(d)
-    const QueryMatch *match = d->matchesById.value(id, 0);
+    const QueryMatch *match = d->matchesById.value(id, nullptr);
     UNLOCK(d)
 
     if (match) {
         return *match;
     }
 
-    return QueryMatch(0);
+    return QueryMatch(nullptr);
 }
 
 void RunnerContext::setSingleRunnerQueryMode(bool enabled)
