@@ -25,16 +25,12 @@
 #include <QTimer>
 #include <QCoreApplication>
 #include <qstandardpaths.h>
-#include <QDebug>
 #include "krunner_debug.h"
 
 #include <ksharedconfig.h>
 #include <kplugininfo.h>
 #include <kservicetypetrader.h>
 
-#include <solid/device.h>
-#include <solid/deviceinterface.h>
-
 #include <ThreadWeaver/DebuggingAids>
 #include <ThreadWeaver/Queue>
 #include <ThreadWeaver/Thread>
@@ -100,20 +96,9 @@ public:
     {
         KConfigGroup config = configGroup();
 
-        //The number of threads used scales with the number of processors.
-        const int numProcs =
-            qMax(Solid::Device::listFromType(Solid::DeviceInterface::Processor).count(), 1);
-        //This entry allows to define a hard upper limit independent of the number of processors.
-        const int maxThreads = config.readEntry("maxThreads", 16);
-        const int numThreads = qMin(maxThreads, 2 + ((numProcs - 1) * 2));
-        //qCDebug(KRUNNER) << "setting up" << numThreads << "threads for" << numProcs << "processors";
-        if (numThreads > Queue::instance()->maximumNumberOfThreads()) {
-            Queue::instance()->setMaximumNumberOfThreads(numThreads);
-        }
         // Limit the number of instances of a single normal speed runner and all of the slow runners
         // to half the number of threads
-        const int cap = qMax(2, numThreads/2);
-        DefaultRunnerPolicy::instance().setCap(cap);
+        DefaultRunnerPolicy::instance().setCap(qMax(2, Queue::instance()->maximumNumberOfThreads() / 2));
 
         enabledCategories = config.readEntry("enabledCategories", QStringList());
         context.restore(config);
@@ -215,6 +200,7 @@ public:
                     runner = loadInstalledRunner(description.service());
                 } else {
                     runner = runners.value(runnerName);
+                    runner->reloadConfiguration();
                 }
 
                 if (runner) {
@@ -222,7 +208,7 @@ public:
                     allCategories << categories;
 
                     bool allCategoriesDisabled = true;
-                    Q_FOREACH (const QString &cat, categories) {
+                    for (const QString &cat : categories) {
                         if (enabledCategories.contains(cat)) {
                             allCategoriesDisabled = false;
                             break;
@@ -533,7 +519,8 @@ QStringList RunnerManager::enabledCategories() const
     KConfigGroup config = d->configGroup();
     QStringList list = config.readEntry("enabledCategories", QStringList());
     if (list.isEmpty()) {
-        Q_FOREACH (AbstractRunner* runner, d->runners) {
+        list.reserve(d->runners.count());
+        for (AbstractRunner* runner : qAsConst(d->runners)) {
             list << runner->categories();
         }
     }
@@ -568,7 +555,7 @@ AbstractRunner* RunnerManager::runner(const QString &name) const
         d->loadRunners();
     }
 
-    return d->runners.value(name, 0);
+    return d->runners.value(name, nullptr);
 }
 
 AbstractRunner *RunnerManager::singleModeRunner() const
@@ -706,9 +693,9 @@ KPluginInfo::List RunnerManager::listRunnerInfo(const QString &parentApp)
 {
     QString constraint;
     if (parentApp.isEmpty()) {
-        constraint.append("not exist [X-KDE-ParentApp]");
+        constraint.append(QStringLiteral("not exist [X-KDE-ParentApp]"));
     } else {
-        constraint.append("[X-KDE-ParentApp] == '").append(parentApp).append("'");
+        constraint.append(QStringLiteral("[X-KDE-ParentApp] == '")).append(parentApp).append(QStringLiteral("'"));
     }
 
     KService::List offers = KServiceTypeTrader::self()->query(QStringLiteral("Plasma/Runner"), constraint);
